;;; web.el --- Settings for web stuff. -*- lexical-binding: t; -*-

;; Time-stamp: <2020-05-24T22:54:55+0200>

;;; Commentary:

;;; Code:

(require 'basics/package-management)

;; Use company auto-completion for (X)HTML.
(use-package company-web
  :demand t
  :after (company)
  :config (add-to-list 'company-backends 'company-web-html))

(use-package web-mode
  :custom
  (web-mode-markup-indent-offset 2)     ; Default indentation level.
  :mode (("\\.[ps]?html?$" . web-mode)
         ("\\.tmpl$" . web-mode)        ; Gitea templates.
         ("\\.php$" . web-mode))
  :hook (web-mode  . (lambda () (set-fill-column 100))))

;; Read EPUB ebooks.
(use-package nov
  :custom (nov-text-width fill-column)
  :custom-face (variable-pitch ((t (:inherit variable-pitch
                                             :family "Source Serif Pro"
                                             :height 1.4))))
  :mode ("\\.epub$" . nov-mode))

;; Mode for writing blog posts with hugo.
(when (string= (system-name) "ventiloplattform")
  (use-package easy-hugo
    :custom ((easy-hugo-basedir "~/Projekte/www/blog.tastytea.de/")
             (easy-hugo-url "https://blog.tastytea.de")
             (easy-hugo-postdir "content/posts")
             (easy-hugo-previewtime (* 60 60 2))
             (easy-hugo-default-ext ".adoc")
             (easy-hugo-asciidoc-extension "adoc")
             (easy-hugo-server-flags "-D")
             (easy-hugo-bloglist        ; Additional blogs.
              '(((easy-hugo-basedir . "~/Projekte/www/text-en.tastytea.de/")
                 (easy-hugo-url . "https://text-en.tastytea.de")
                 (easy-hugo-postdir . "content/posts")
                 (easy-hugo-previewtime . (* 60 60 2)))
                ((easy-hugo-basedir . "~/Projekte/www/text-de.tastytea.de/")
                 (easy-hugo-url . "https://text-de.tastytea.de")
                 (easy-hugo-postdir . "content/posts")
                 (easy-hugo-previewtime . (* 60 60 2))))))
    :bind ("C-c h" . easy-hugo)))

(provide 'text/web)
;;; web.el ends here
