;;; init.el --- tastytea's Emacs init file. -*- lexical-binding: t; -*-

;; Time-stamp: <2020-06-02T15:07:00+0200>

;;; Commentary:
;; Requires at least Emacs 26.

;;; Code:

;; early-init.el is automatically loaded in Emacs 27+.
(when (< emacs-major-version 27)
  (require 'early-init (expand-file-name "early-init.el" user-emacs-directory)))

(customize-set-variable
 'gc-cons-threshold (* 20 1024 1024)
 "Set garbage collection threshold to 20 MiB to speed up init.")

;; Add path to init files.
(push (expand-file-name "init.d" user-emacs-directory) load-path)

(require 'basics/package-management)
(require 'basics/early-packages)
(require 'basics/global-variables)
(require 'basics/input)
(require 'basics/buffers)
(require 'basics/appearance)
(require 'basics/ui)

(require 'text/common)
(require 'text/latex)
(require 'text/web)
(require 'text/misc)

(require 'misc/documentation)
(require 'misc/email)
(require 'misc/misc)
(require 'misc/libs)

(require 'programming/common)
(require 'programming/lsp)
(require 'programming/git)
(require 'programming/c++)
(require 'programming/elisp)
(require 'programming/misc)

(require 'net/server)
(require 'net/client)

(customize-set-variable 'gc-cons-threshold
                        (car (get 'gc-cons-threshold 'standard-value))
                        "Set garbage collection threshold to original value.")

(provide 'init)
;;; init.el ends here
